package com.ruoyi.tcZz.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.tcZz.domain.TcAqg;
import com.ruoyi.tcZz.domain.TcQlzxxdsjtj;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.tcZz.domain.TcSdtb;
import com.ruoyi.tcZz.service.ITcSdtbService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;
import org.springframework.web.multipart.MultipartFile;

/**
 * 属地通报Controller
 *
 * @author ruoyi
 * @date 2023-10-12
 */
@RestController
@Api(tags = "属地通报")
@RequestMapping("/tcZz/networkSecurity/sdtb")
public class TcSdtbController extends BaseController {
    @Autowired
    private ITcSdtbService tcSdtbService;

    /**
     * 查询属地通报列表
     */
    @ApiOperation(value = "查询属地通报列表", response = TcSdtb.class)
    @GetMapping("/list")
    public TableDataInfo list(TcSdtb tcSdtb) {
        startPage();
        List<TcSdtb> list = tcSdtbService.selectTcSdtbList(tcSdtb);
        return getDataTable(list);
    }

    /**
     * 导出属地通报列表
     */
    @ApiOperation(value = "导出属地通报列表")
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcSdtb tcSdtb) {
        List<TcSdtb> list = tcSdtbService.selectTcSdtbList(tcSdtb);
        ExcelUtil<TcSdtb> util = new ExcelUtil<TcSdtb>(TcSdtb.class);
        util.exportExcel(response, list, "属地通报数据");
    }

    /**
     * 获取属地通报详细信息
     */
    @ApiOperation(value = "获取属地通报详细信息")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(tcSdtbService.selectTcSdtbById(id));
    }

    /**
     * 新增属地通报
     */
    @ApiOperation(value = "新增属地通报")
    @PostMapping
    public AjaxResult add(@RequestBody TcSdtb tcSdtb) {
        return toAjax(tcSdtbService.insertTcSdtb(tcSdtb));
    }

    /**
     * 修改属地通报
     */
    @ApiOperation(value = "修改属地通报")
    @PutMapping
    public AjaxResult edit(@RequestBody TcSdtb tcSdtb) {
        return toAjax(tcSdtbService.updateTcSdtb(tcSdtb));
    }

    /**
     * 删除属地通报
     */
    @ApiOperation(value = "删除属地通报")
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(tcSdtbService.deleteTcSdtbByIds(ids));
    }

    /**
     * 导入
     */
    @ApiOperation("通用导入excel信息")
    @PostMapping("/common/importExcel")
    public AjaxResult importExcel(MultipartFile file) throws Exception {
        ExcelUtil<TcSdtb> util = new ExcelUtil<TcSdtb>(TcSdtb.class);
        List<TcSdtb> tcSdtbList = util.importExcel(file.getInputStream());
        tcSdtbService.importUser(tcSdtbList);
        return AjaxResult.success();
    }

    /**
     * 批量启用禁用
     *
     * @param isStatus 启用禁用状态
     * @return
     */

    @ApiOperation("批量启用禁用")
    @GetMapping("/isStatus")
    public AjaxResult isStatus(@RequestParam("isStatus") Integer isStatus, @RequestParam("ids") List<String> ids) {
        tcSdtbService.updateByisStatus(isStatus,ids);
        return AjaxResult.success();
    }

    @ApiOperation("通用下载excel模板")
    @PostMapping("/importTemplate")
    public void importTemplate(HttpServletResponse response)
    {
        ExcelUtil<TcSdtb> util = new ExcelUtil<TcSdtb>(TcSdtb.class);
        util.importTemplateExcel(response, " 属地通报");
    }
}
